#
# spec file for package python-python-lsp-black
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-python-lsp-black
Version:        1.3.0
Release:        2.1
Summary:        Black plugin for the Python LSP Server
License:        MIT
URL:            https://github.com/python-lsp/python-lsp-black
Source:         https://github.com/python-lsp/python-lsp-black/archive/refs/tags/v%{version}.tar.gz#/python-lsp-black-%{version}-gh.tar.gz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module black >= 22.3.0}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-lsp-server >= 1.4.0}
BuildRequires:  %{python_module tomli if %python-base < 3.11}
# /SECTION
BuildRequires:  fdupes
Requires:       python-black >= 22.3.0
Requires:       python-python-lsp-server >= 1.4
%if 0%{?python_version_nodots} < 311
Requires:       python-tomli
%endif
BuildArch:      noarch
%python_subpackages

%description
Black plugin for the Python LSP Server

To avoid unexpected results you should make sure yapf and autopep8 are not installed.

- pyls-black can either format an entire file or just the selected text.
- The code will only be formatted if it is syntactically valid Python.
- Text selections are treated as if they were a separate Python file.
  Unfortunately this means you can't format an indented block of code.
- python-lsp-black will use your project's pyproject.toml if it has one.

%prep
%setup -q -n python-lsp-black-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.md
%{python_sitelib}/pylsp_black
%{python_sitelib}/python_lsp_black-%{version}.dist-info

%changelog
* Wed Nov  1 2023 Ben Greiner <code@bnavigator.de>
- Revert the last change. The error message was genuine and showed
  a dependency issue.
* Wed Nov  1 2023 Steve Kowalik <steven.kowalik@suse.com>
- Be clear that we require lsp-jsonrpc, because the test suite does.
* Sat Jul  1 2023 Ben Greiner <code@bnavigator.de>
- Update to 1.3.0
  * Support for black's preview and skip-magic-trailing-comma
    config options.
  * Better TOML support.
* Thu Oct 27 2022 Ben Greiner <code@bnavigator.de>
- Update to 1.2.1
  * This release disables autopep8 and yapf plugins to avoid
    conflicts with black.
  * black minimum version has been increased to 22.3.0 because of
    an incompatibility with new versions of click.
- Enable test suite
* Sat Apr  9 2022 Ben Greiner <code@bnavigator.de>
- Fix runtime requirement for black
* Sat Apr  9 2022 Ben Greiner <code@bnavigator.de>
- Update to 1.2.0
  * This release fixes formatting of Python files with non-UNIX
    line endings, adds plugin configuration support and black
    configuration caching to improve performance.
  * Official support for Python 3.10 by @wlcx (PR 31).
  * Correctly format files and ranges with line endings other than
    LF by @ccordoba12 (PR 28).
  * Plugin configuration support and black configuration caching by
    @ccordoba12 and @haplo (PR 26).
  * Fixed PyPI badge in Readme (PR 32).
  * Updated pre-commit hooks' versions (PR 33).
* Fri Mar 25 2022 Ben Greiner <code@bnavigator.de>
- Update to 1.1.0
  * Support global config as a fallback by @jdost in #19
  * Fix TypeError when formatting with black 22.1.0+ by @wlcx in
    [#30]
* Tue Jul 13 2021 Ben Greiner <code@bnavigator.de>
- Initial specfile for version 1.0.0
  * The python-lsp-server version for python-pyls-black, which was
    for the python-python-language-server abandoned by upstream.
  * required by spyder.
